@@ -1,9 +1,8 @@
 from __future__ import annotations
-from typing import Tuple, final
 import numpy as np
 
 from torusgrid.fields import RealField2D
-from torusgrid.dynamics import SecondOrderRK4, FirstOrderRK4, TemporalEvolver
+from torusgrid.dynamics import FirstOrderRK4, TemporalEvolver
 import torusgrid as tg
 
 
@@ -51,16 +50,33 @@ class NonlocalConservedMinimizer(TemporalEvolver[RealField2D], MinimizerMixin):
         self.data['minimizer'] = 'nonlocal'
 
 
-# class NonlocalConservedRK4(SecondOrderRK4[RealField2D], MinimizerMixin):
 class NonlocalConservedRK4(NonlocalConservedRK4Base, MinimizerMixin):
-    """
+    r"""
     RK4 nonlocal conserved dynamics with inertia
+
+    The evolution equations are
+
+        .. math::
+
+            \dot\psi = M \phi
+
+        .. math::
+
+            \dot\phi = - \left(\phi + \frac{\delta F}{\delta \psi}\Big\vert_{k\neq 0}\right)
+
     """
     def __init__(self, 
             field: RealField2D, 
             dt: tg.FloatLike, eps: tg.FloatLike, *,
             k_regularizer: tg.FloatLike=0.1, 
             inertia: tg.FloatLike=100):
+        """
+        :param field: the PFC field to be minimized
+        :param dt: time step
+        :param eps: PFC epsilon
+        :param k_regularizer: k-space regulator to suppress high frequency modes from blowing up
+        :param inertia: coefficient of 1st time derivative
+        """
 
         super().__init__(field, dt, 
                          k_regularizer=k_regularizer, inertia=inertia)
@@ -151,3 +167,4 @@ class NonlocalDescent(TemporalEvolver[RealField2D], MinimizerMixin):
         self.data['R'] = self.R
 
 
+
